Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(940)

Unified Diff: third_party/WebKit/Source/platform/graphics/paint/PaintChunker.h

Issue 1397583002: Implement the framework for a paint property hierarchy (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Job insecurity: better tests, better comments, better names. Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/paint/PaintChunker.h
diff --git a/third_party/WebKit/Source/platform/graphics/paint/PaintChunker.h b/third_party/WebKit/Source/platform/graphics/paint/PaintChunker.h
index 33f5a7af3ef67a63ce6aebbd094950b6689fcace..d99bd34963828e8a48d7156f39f5fb05b7ff1375 100644
--- a/third_party/WebKit/Source/platform/graphics/paint/PaintChunker.h
+++ b/third_party/WebKit/Source/platform/graphics/paint/PaintChunker.h
@@ -7,22 +7,22 @@
#include "platform/PlatformExport.h"
#include "platform/graphics/paint/PaintChunk.h"
-#include "platform/graphics/paint/PaintProperties.h"
+#include "platform/graphics/paint/PaintChunkProperties.h"
#include "wtf/Vector.h"
namespace blink {
// Accepts information about changes to |PaintProperties| as drawings are
// accumulated, and produces a series of paint chunks: contiguous ranges of the
// display list with identical |PaintProperties|.
class PLATFORM_EXPORT PaintChunker {
public:
PaintChunker();
~PaintChunker();
- bool isInInitialState() const { return m_chunks.isEmpty() && m_currentProperties == PaintProperties(); }
+ bool isInInitialState() const { return m_chunks.isEmpty() && m_currentProperties == PaintChunkProperties(); }
- void updateCurrentPaintProperties(const PaintProperties&);
+ void updateCurrentPaintChunkProperties(const PaintChunkProperties&);
void incrementDisplayItemIndex();
void decrementDisplayItemIndex();
@@ -33,7 +33,7 @@ public:
private:
Vector<PaintChunk> m_chunks;
- PaintProperties m_currentProperties;
+ PaintChunkProperties m_currentProperties;
};
} // namespace blink
@@ -7,22 +7,22 @@
#include "wtf/Vector.h"
namespace blink {
-// Accepts information about changes to |PaintProperties| as drawings are
+// Accepts information about changes to |PaintChunkProperties| as drawings are
// accumulated, and produces a series of paint chunks: contiguous ranges of the
@@ -7,22 +7,22 @@
// accumulated, and produces a series of paint chunks: contiguous ranges of the
-// display list with identical |PaintProperties|.
+// display list with identical |PaintChunkProperties|.
class PLATFORM_EXPORT PaintChunker {
public:

Powered by Google App Engine
This is Rietveld 408576698